"""For help on EMAN, look up libpyEM instead of EMAN"""
from libpyEM import *
import os, os.path
import tempfile

EMData.MRC = Image.mrc
EMData.SPIDER = Image.spider
EMData.IMAGIC = Image.img
EMData.PGM = Image.pgm
EMData.LST = Image.lst
EMData.PIF = Image.pif
EMData.PNG = Image.png
EMData.DM3 = Image.dm3
EMData.TIF = Image.tif
EMData.VTK = Image.vtk
EMData.SAL = Image.sal
EMData.ICOS = Image.map
EMData.IMAGIC3D = Image.img3d
EMData.EMIM = Image.emim
EMData.SINGLE_SPIDER = Image.single_spider
EMData.GATAN = Image.dm2
EMData.AMIRA = Image.amira
EMData.XPLOR = Image.xplor
EMData.ANY = Image.any

Euler.EMAN = EulerType.eman
Euler.IMAGIC = EulerType.imagic
Euler.SPIN = EulerType.spin
Euler.QUAT = EulerType.quat
Euler.MATRIX = EulerType.matrix
Euler.SGIROT = EulerType.sgirot
Euler.SPIDER = EulerType.spider
Euler.MRC = EulerType.mrc

def displayphase(img):
	"""This will display complex phases of a single image"""
	fsp=os.path.basename(tempfile.mktemp())+".mrc"
	if (img.isComplex()) : f=img
	else: f=img.doFFT()
	f.toCorner()
	f.ri2ap()
	for i in range(0,f.xSize()*f.ySize(),2):
		f.setValueAt(i,0,0,f.valueAt(i+1,0,0))
		f.setValueAt(i+1,0,0,0)
	f.ap2ri()

	f.writeImage(fsp)
	os.system("v2 "+fsp)
	os.unlink(fsp)

def display(lst) :
	"""This is used to display a list of EMData objects"""
	fspbase = os.path.basename(tempfile.mktemp())
	fspimg = fspbase + ".img"
	fsphed = fspbase + ".hed"
	
	for i in lst:
		i.writeImage(fspimg, -1, Image.img)

	os.system("v2 " + fspimg)
	os.unlink(fspimg)
	os.unlink(fsphed)

def triplot(tuplelist):
	"""this will display a list of 2 or 3 tuples in a 'triview'"""
	out=os.popen("triplot -&","w")
	for i in tuplelist:
		if (len(i)==2) : out.write("%f\t%f\n"%(float(i[0]),float(i[1])))
		elif (len(i)>2) : out.write("%f\t%f\t%f\n"%(float(i[0]),float(i[1]),float(i[2])))
	out.close()

def LOGbegin(ARGV):
	out=open(".emanlog","a")
	b=string.split(ARGV[0],'/')
	ARGV[0]=b[len(b)-1]
	out.write("%d\t%d\t1\t%d\t%s\n"%(os.getpid(),time.time(),os.getppid(),string.join(ARGV," ")))
	out.close()

def LOGend():
	out=open(".emanlog","a")
	out.write("%d\t%d\t2\t-\t\n"%(os.getpid(),time.time()))
	out.close()
